RouteModel class abstract

RouteModel

Properties:

Available extensions
Annotations
  • @BuiltValue.new()

Constructors

RouteModel([void updates(RouteModelBuilder b)])
factory

Properties

advanceWaypointId String?
no setter
description String
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
waypointIds → BuiltList<String>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RouteModelBuilder)) RouteModel
Rebuilds the instance.
inherited
toBuilder() RouteModelBuilder
Converts the instance to a builder B.
inherited
toPb() Route

Available on RouteModel, provided by the RouteModelExt extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RouteModel>
no setter